Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(367)

Unified Diff: third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js

Issue 2238883004: DevTools: Split off SourcesTextEditor from CodeMirrorTextEditor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Stray line Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/devtools/front_end/source_frame/module.json ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
diff --git a/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js b/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
index 603e2038e330ce804eba7fd160a09c3243f41fb5..58aa54146e58d6a6fb7fa7ecf487e949c7be7080 100644
--- a/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
+++ b/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
@@ -48,7 +48,7 @@ WebInspector.JavaScriptSourceFrame = function(uiSourceCode)
this.textEditor.element.addEventListener("keydown", this._onKeyDown.bind(this), true);
- this.textEditor.addEventListener(WebInspector.CodeMirrorTextEditor.Events.GutterClick, this._handleGutterClick.bind(this), this);
+ this.textEditor.addEventListener(WebInspector.SourcesTextEditor.Events.GutterClick, this._handleGutterClick.bind(this), this);
this._breakpointManager.addEventListener(WebInspector.BreakpointManager.Events.BreakpointAdded, this._breakpointAdded, this);
this._breakpointManager.addEventListener(WebInspector.BreakpointManager.Events.BreakpointRemoved, this._breakpointRemoved, this);
@@ -197,7 +197,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
{
WebInspector.UISourceCodeFrame.prototype.wasShown.call(this);
if (this._executionLocation && this.loaded) {
// We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/499889
setImmediate(this._generateValuesInSource.bind(this));
}
},
@@ -648,7 +648,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
this.textEditor.setExecutionLocation(uiLocation.lineNumber, uiLocation.columnNumber);
if (this.isShowing()) {
// We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/506566
setImmediate(this._generateValuesInSource.bind(this));
}
},
@@ -997,7 +997,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
if (this._muted)
return;
- var eventData = /** @type {!WebInspector.CodeMirrorTextEditor.GutterClickEventData} */ (event.data);
+ var eventData = /** @type {!WebInspector.SourcesTextEditor.GutterClickEventData} */ (event.data);
var lineNumber = eventData.lineNumber;
var eventObject = eventData.event;
« no previous file with comments | « third_party/WebKit/Source/devtools/front_end/source_frame/module.json ('k') | no next file » | no next file with comments »
@@ -197,7 +197,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
WebInspector.UISourceCodeFrame.prototype.wasShown.call(this);
if (this._executionLocation && this.loaded) {
- // We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/499889
+ // We need SourcesTextEditor to be initialized prior to this call. @see crbug.com/499889
setImmediate(this._generateValuesInSource.bind(this));
}
@@ -648,7 +648,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
this.textEditor.setExecutionLocation(uiLocation.lineNumber, uiLocation.columnNumber);
if (this.isShowing()) {
- // We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/506566
+ // We need SourcesTextEditor to be initialized prior to this call. @see crbug.com/506566
setImmediate(this._generateValuesInSource.bind(this));
}

Powered by Google App Engine
This is Rietveld 408576698